// if libgrio has no sources, it doesn't get built correctly

static int gr_bug_work_around_6;
